#api 信息表
DROP TABLE IF EXISTS `t_api_interface`;
CREATE TABLE `t_api_interface` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'api 信息表自增ID',
  `api_key`     varchar(200) NOT NULL COMMENT 'api唯一标识',
  `api_name`    varchar(100) DEFAULT NULL COMMENT 'api名称',
  `api_desc`    varchar(300) DEFAULT NULL COMMENT 'api描述',
  `api_protocl` varchar(32)  DEFAULT NULL COMMENT 'api请求协议：http，https',
  `target_url`  varchar(100) DEFAULT NULL COMMENT '目标url',
  `status`      varchar(20)  NOT NULL COMMENT '状态(1-草稿 2-发布 3-过时 4-冻结 5-失效)',
  `version`     varchar(20)  DEFAULT NULL COMMENT '版本号',
  `sign_type`   varchar(50)  DEFAULT NULL COMMENT '加密方式： MD5 RSA',
  `timeout`     varchar(50)  DEFAULT NULL COMMENT '超时时间',
  `is_test`     tinyint(2)   NOT NULL DEFAULT '0' COMMENT '是否测试数据:0 否,1 是',
  `remark`      varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date` datetime     NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user` varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user` varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`  tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`),
  UNIQUE KEY `api_key_unique` (`api_key`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='api信息表';



#api组织信息表
DROP TABLE IF EXISTS `t_api_org`;
CREATE TABLE `t_api_org` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'api组织信息表自增ID',
  `org_code` varchar(200) NOT NULL COMMENT '组织编码(组织唯一标识)',
  `org_name` varchar(100) DEFAULT NULL COMMENT '组织名称',
  `org_desc` varchar(300) DEFAULT NULL COMMENT '组织描述',
  `org_cn_name` varchar(100) DEFAULT NULL COMMENT '组织英文名称',
  `status`   varchar(100) NOT NULL COMMENT '状态(1-正常 2-冻结 3-下架)',
  `org_mail`   varchar(100) DEFAULT NULL COMMENT '组织邮箱',
  `org_sort`   int(10) DEFAULT '999' COMMENT '组织排序',
  `parent_id`  varchar(100) DEFAULT NULL COMMENT '父类组织编码',
  `remark`     varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user` varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user` varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`  tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`),
  UNIQUE KEY `org_code_unique`(`org_code`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='api组织信息表';


#api授权信息表
DROP TABLE IF EXISTS `t_api_auth`;
CREATE TABLE `t_api_auth` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'api授权信息表自增ID',
  `api_interface_id` bigint(20) NOT NULL COMMENT 'api信息表id',
  `api_org_id`   bigint(20) NOT NULL COMMENT 'api组织id',
  `auth_type`    varchar(20) DEFAULT NULL COMMENT '授权类型:1.数据银行购买 2.dmp授权',
  `auth_code`    varchar(100) DEFAULT NULL COMMENT '授权码',
  `salt`         varchar(200) DEFAULT NULL COMMENT '盐值',
  `auth_mode`    varchar(20) DEFAULT NULL COMMENT '授权方式:1.按次调用 2.按月调用 3.按季调用 4.按年调用',
  `valid_start_time`  datetime  DEFAULT NULL COMMENT '开始时间',
  `valid_end_time`    datetime  DEFAULT NULL COMMENT '结束时间',
  `status`       varchar(100) NOT NULL COMMENT '状态(1-正常 2-作废)',
  `remark`       varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date`  datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user`  varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date`  datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user`  varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`   tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='api授权信息表';




#api请求日志表
DROP TABLE IF EXISTS `t_api_req_log`;
CREATE TABLE `t_api_req_log` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'api授权信息表自增ID',
  `request_ip`     varchar(64) DEFAULT NULL COMMENT '请求ip',
  `api_key`        varchar(100) DEFAULT NULL COMMENT 'apikey',
  `request_params` text COMMENT '请求参数',
  `response_params`text COMMENT '返回参数',
  `request_url`    varchar(64) DEFAULT NULL COMMENT '请求路径',
  `request_method` varchar(100) DEFAULT NULL COMMENT '请求方法',
  `request_type`   varchar(20) DEFAULT NULL COMMENT '请求类型（方式）',
  `encry_mode`     varchar(20) DEFAULT NULL COMMENT '加密方式:MD5,RSA',
  `trans_mode`     varchar(20) DEFAULT NULL COMMENT '传输方式:POST,GET',
  `request_token`  varchar(64) DEFAULT NULL COMMENT '客户请求token',
  `request_time`   datetime DEFAULT NULL COMMENT '请求时间',
  `remark`         varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user`    varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user`    varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`     tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='api请求日志表';



#apiEs字段信息表
DROP TABLE IF EXISTS `t_api_open_api_es_fields`;
CREATE TABLE `t_api_open_api_es_fields` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'apiEs字段信息表自增ID',
  `es_database`     varchar(100) DEFAULT NULL COMMENT '源数据库',
  `es_table`        varchar(100) DEFAULT NULL COMMENT '源表',
  `field_name`      varchar(50)  DEFAULT NULL COMMENT '字段名称',
  `field_type`      varchar(50)  DEFAULT NULL COMMENT '字段类型',
  `field_desc`      varchar(200) DEFAULT NULL COMMENT '字段描述',
  `remark`         varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user`    varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user`    varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`     tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='apiEs字段信息表';

#apiEs配置信息表
DROP TABLE IF EXISTS `t_api_open_api_es_tagconfig`;
CREATE TABLE `t_api_open_api_es_tagconfig` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'apiEs字段信息表自增ID',
  `project_id`      bigint(20) DEFAULT NULL COMMENT '工程id',
  `app_id`          varchar(100)  DEFAULT NULL COMMENT 'app_id',
  `api_id`          varchar(100)  DEFAULT NULL COMMENT 'api_id',
  `api_type`        varchar(50)  DEFAULT NULL COMMENT 'api类型',
  `api_key`         varchar(200) NOT NULL COMMENT 'api唯一标识',
  `es_data_source`  varchar(100) DEFAULT NULL COMMENT '数据源id',
  `es_data_base`    varchar(100) DEFAULT NULL COMMENT '源数据库名称',
  `es_table`        varchar(100) DEFAULT NULL COMMENT '源数据表名称',
  `request_param`   json         DEFAULT NULL COMMENT '请求参数集合',
  `result_param`    json         DEFAULT NULL COMMENT '响应参数集合',
  `page`            varchar(50) DEFAULT NULL COMMENT '是否分页',
  `handle_type`     varchar(50) DEFAULT NULL COMMENT '处理类型',
  `remark`         varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user`    varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user`    varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`     tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='apiEs配置信息表';


#api数据源配置信息表
DROP TABLE IF EXISTS `t_api_syncing_datasource`;
CREATE TABLE `t_api_syncing_datasource` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'api数据源配置信息表自增ID',
  `datasource_type`   bigint(20) DEFAULT NULL COMMENT '数据源类型ID',
  `datasource_name`   varchar(100)  DEFAULT NULL COMMENT '数据源名称',
  `datasource_desc`   varchar(100)  DEFAULT NULL COMMENT '数据源描述',
  `project_id` 		  bigint(20)  DEFAULT NULL COMMENT '项目编号',
  `jdbc_url`  		  varchar(50)  DEFAULT NULL COMMENT 'JDBC URL',
  `db_name` 		  varchar(100) DEFAULT NULL COMMENT '数据库名',
  `user_name` 		  varchar(100) DEFAULT NULL COMMENT '账号',
  `password` 		  varchar(100) DEFAULT NULL COMMENT '密码',
  `endpoint` 		  json         DEFAULT NULL COMMENT '终端信息',
  `bucket` 			  json         DEFAULT NULL COMMENT 'Bucket信息',
  `access_id` 		  varchar(50) DEFAULT NULL COMMENT 'accessId',
  `access_key` 		  varchar(50) DEFAULT NULL COMMENT 'accessKey',
  `protocol` 		varchar(64) DEFAULT NULL COMMENT 'FTP协议',
  `host` 			varchar(64) DEFAULT NULL COMMENT 'IP',
  `port` 			varchar(64) DEFAULT NULL COMMENT '端口',
  `default_fs` 		varchar(64) DEFAULT NULL COMMENT 'NameNode地址',
  `table_schema` 	varchar(64) DEFAULT NULL COMMENT '表空间',
  `data_status` 	char(1) NOT NULL DEFAULT '1' COMMENT '数据状态',
  `remark`         varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user`    varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user`    varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`     tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='api数据源配置信息表';


#api数据源类型信息表
DROP TABLE IF EXISTS `t_api_syncing_datasource_type`;
CREATE TABLE `t_api_syncing_datasource_type` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT COMMENT 'apiEs字段信息表自增ID',
  `datasource`          varchar(64) DEFAULT NULL COMMENT '数据源名称',
  `datasource_catecode` varchar(32) DEFAULT NULL COMMENT '数据源分类编码',
  `datasource_catename` varchar(32) DEFAULT NULL COMMENT '数据源分类名称',
  `datasource_type`     varchar(32) DEFAULT NULL COMMENT '数据源类型',
  `img_url`             varchar(128) DEFAULT NULL COMMENT '数据源图标',
  `data_status`         char(1) DEFAULT NULL COMMENT '状态',
  `is_enabled`          char(1) DEFAULT NULL COMMENT '是否启用',
  `datasource_catetype` varchar(6) DEFAULT NULL,
  `driver_class_name`   varchar(64) DEFAULT NULL,
  `is_enable_test`      char(1) DEFAULT NULL COMMENT '是否启用测试',
  `default_source_script` longblob,
  `default_target_script` longblob,
  `is_enable_source`     char(1) DEFAULT NULL  COMMENT '是否启用源',
  `is_enable_target`     char(1) DEFAULT NULL  COMMENT '是否启用目标',
  `remark`         varchar(500) DEFAULT NULL COMMENT '备注',
  `create_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `create_user`    varchar(100) DEFAULT NULL COMMENT '创建人',
  `update_date`    datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `update_user`    varchar(100) DEFAULT NULL COMMENT '更新人',
  `is_deleted`     tinyint(2) unsigned NOT NULL DEFAULT '0' COMMENT '是否删除',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 ROW_FORMAT=DYNAMIC COMMENT='api数据源类型信息表';